@@ -6,10 +6,20 @@ from typing import Any
 from typing import Dict
 from typing import List
 
+try:
+    import pop_conf.conf  # noqa
+
+    HAS_LIBS = (True,)
+except ImportError as e:
+    HAS_LIBS = False, str(e)
+
 
 def __virtual__(hub):
+    return HAS_LIBS
+
+
+def __init__(hub):
     hub.pop.sub.add("pop_conf.conf")
-    return hasattr(hub.conf, "integrate"), "pop-conf is not installed"
 
 
 def integrate(
