@@ -3,6 +3,11 @@ from typing import List
 import pop.hub
 
 
+def __virtual__(hub):
+    hub.pop.sub.add(dyne_name="config")
+    return hasattr(hub.config, "integrate"), "pop-config is not installed"
+
+
 def load(
     hub: "pop.hub.Hub",
     sources: List[str],
@@ -16,5 +21,4 @@ def load(
     Use the pop-config system to load up a fresh configuration for this project
     from the included conf.py file.
     """
-    hub.pop.sub.add(dyne_name="config")
     hub.config.integrate.load(sources, cli, dyne_name, loader, parse_cli, logs)
