@@ -9,7 +9,7 @@ from typing import Callable
 from typing import Coroutine
 from typing import Iterable
 
-import proxy_tools
+import lazy_object_proxy
 
 import pop.contract
 import pop.hub
@@ -23,7 +23,7 @@ def __init__(hub):
     hub.pop.loop.EXECUTOR = None
     hub.pop.loop.POLICY = None
     hub.pop.sub.add(dyne_name="loop")
-    hub.pop.Loop = proxy_tools.module_property(hub.loop.init.get)
+    hub.pop.Loop = lazy_object_proxy.Proxy(hub.loop.init.get)
 
 
 def create(hub, loop_plugin: str = None):
