@@ -70,6 +70,9 @@ def add(
     if dyne_name:
         subname = subname if subname else dyne_name
     root = sub or hub
+    # The dynamic namespace is already on the hub
+    if dyne_name in root._subs:
+        return
     root._subs[subname] = pop.hub.Sub(
         hub,
         subname,
